### Latest release (2017-02-22)

#### v1.11.1

- fix(js): fix #2439, `filterBy` cannot filter array keys
- fix(js): fix #2424, from html with checkbox bug
- fix(js): fix #2385, checkbox render bug with formatter
- fix(js): fix #750, showRow and hideRow bug
- fix(js): fix #2387, page list bug
- fix(js): decrement totalRows on remove if using server side pagination
- fix(js): bug in the calculation of toolbar and pagination heights
- feat(js): fix #2414, add `paginationLoop` option
- feat(js): update method `getRowsHidden` to `getHiddenRows`
- feat(js): add `sortClass` option
- feat(js): add `totalField` Option
- feat(js): add 'pageNumber' and 'pageSize' to 'refresh' method
- feat(js): add `escape` column option
- fix(js): fix #2461, adding the initPagination call to updateByUniqueId and updateRow methods
- fix(js): fix #2879, IE8 bug
- fix(js): fix #2719, remove `tabindex`
- fix(css): fix #2208, dropdown-menu style bug
- fix(filter-control extension): fix #2418, `height` cause datepicker not display the selected date
- fix(export extension): fix #2220, selected rows does not work when data-pagination-side is server
- fix(reorder-row extension): fix #1343, reorder rows bug with pagination
- fix(cookie extension): correction regex to match 'mi'
- feat(locale): fix #2759, add es-CL and uz-UZ locales
- feat(cookie extension): fix #2386, add `getCookies` method
- feat(cookie extension): fix #2371, add `cookieStorage` option
- feat(multiple-selection-row extension): add multiple-selection-row extension
- feat(filter-control extension): fix #1540, disable unnecessary/unused values from select options
- feat(filter-control extension): fix #2448, create a css file which contains the style for this extension
- feat(filter-control extension): fix #2189, set placeholder of the filter-control input
- feat(print extension): add print extension
- feat(auto-refresh extension): add auto refresh extension
- feat(tree-column extension): add tree column extension
